@@ -1,8 +1,10 @@
 package MogileFS::Config;
 use strict;
 require Exporter;
+use MogileFS::ProcManager;
+
 our @ISA = qw(Exporter);
-our @EXPORT = qw($DEBUG config);
+our @EXPORT = qw($DEBUG config set_config);
 
 our ($DEFAULT_CONFIG, $DEFAULT_MOG_ROOT, $MOG_ROOT, $MOGSTORED_STREAM_PORT, $DEBUG, $USE_HTTP);
 $DEBUG = 0;
@@ -12,6 +14,21 @@ $MOGSTORED_STREAM_PORT = 7501;
 
 my %conf;
 sub set_config {
+    shift if @_ == 3;
+    my ($k, $v) = @_;
+
+    # if a child, propogate to parent
+    if (my $worker = MogileFS::ProcManager->is_child) {
+        $worker->send_to_parent(":set_config_from_child $k $v");
+    } else {
+        MogileFS::ProcManager->send_to_all_children(":set_config_from_parent $k $v");
+    }
+
+    return set_config_no_broadcast($k, $v);
+}
+
+sub set_config_no_broadcast {
+    shift if @_ == 3;
     my ($k, $v) = @_;
     return $conf{$k} = $v;
 }
@@ -33,10 +50,12 @@ our (
     $replicate_jobs,
     $reaper_jobs,
     $monitor_jobs,
+    $checker_jobs,
     $mog_root,
     $min_free_space,
     $max_disk_age,
     $node_timeout,          # time in seconds to wait for storage node responses
+    $old_repl_compat,
    );
 
 our $default_mindevcount;
@@ -64,6 +83,8 @@ sub load_config {
                              'minfreespace=i' => \$cmdline{min_free_space},
                              'default_mindevcount=i' => \$cmdline{default_mindevcount},
                              'node_timeout=i' => \$cmdline{node_timeout},
+                             'no_schema_check' => \$cmdline{no_schema_check},
+                             'old_repl_compat=i' => \$cmdline{old_repl_compat},
                              );
 
     # warn of old/deprecated options
@@ -116,22 +137,27 @@ sub load_config {
     $replicate_jobs = choose_value( 'replicate_jobs', 1 );
     $reaper_jobs    = choose_value( 'reaper_jobs', 1 );
     $monitor_jobs   = choose_value( 'monitor_jobs', 1 );
+    $checker_jobs   = choose_value( 'checker_jobs', 1 );
     $min_free_space = choose_value( 'min_free_space', 100 );
     $max_disk_age   = choose_value( 'max_disk_age', 5 );
-    $DEBUG          = choose_value( 'debug', 0, 1 );
+    $DEBUG          = choose_value( 'debug', $ENV{DEBUG} || 0, 1 );
     $USE_HTTP       = ! choose_value( 'no_http', 0, 1);
     $default_mindevcount = choose_value( 'default_mindevcount', 2 );
     $node_timeout   = choose_value( 'node_timeout', 2 );
 
+    $old_repl_compat = choose_value( 'old_repl_compat', 1 );
+
+    choose_value( 'no_schema_check', 0 );
+
     # now load plugins
     load_plugins($cfgfile{plugins}) if $cfgfile{plugins};
 
     choose_value('user', '');
 }
 
-### FUNCTION: choose_value( $name, $default[, $boolean] )
-sub choose_value ($$;$) {
-    my ( $name, $default, $boolean ) = @_;
+### FUNCTION: choose_value( $name, $default )
+sub choose_value {
+    my ( $name, $default ) = @_;
     return set_config($name, $cmdline{$name}) if defined $cmdline{$name};
     return set_config($name, $cfgfile{$name}) if defined $cfgfile{$name};
     return set_config($name, $default);
@@ -146,7 +172,8 @@ sub load_plugins {
 }
 
 sub config {
-    my ($class, $k) = @_;
+    shift if @_ == 2;
+    my $k = shift;
     die "No config variable '$k'" unless defined $conf{$k};
     return $conf{$k};
 }
